![](docs/source/logo.png)

# Bayesian Monte Carlo Markov Chain Regression

[![PyPi](https://img.shields.io/pypi/v/baypy)](https://pypi.org/project/baypy/)
[![PyPi](https://img.shields.io/pypi/pyversions/baypy.svg)](https://pypi.org/project/baypy/)
[![License: GPL v3](https://img.shields.io/badge/License-GPLv3-blue.svg)](https://github.com/AndreaBlengino/baypy/blob/master/LICENSE)

[![Tests](https://github.com/AndreaBlengino/baypy/actions/workflows/tests.yml/badge.svg?branch=master)](https://github.com/AndreaBlengino/baypy/actions/workflows/tests.yml)
[![Documentation Status](https://readthedocs.org/projects/baypy/badge/?version=latest)](https://baypy.readthedocs.io/en/latest/?badge=latest)
[![codecov](https://codecov.io/gh/AndreaBlengino/baypy/graph/badge.svg?token=T7FMO9ACJW)](https://codecov.io/gh/AndreaBlengino/baypy)

**baypy** is a python package for solving bayesian regression models 
through a Monte Carlo Markov chain sampling.

## References

- [Source code](https://github.com/AndreaBlengino/baypy/tree/master/baypy)  
- [Issue tracker](https://github.com/AndreaBlengino/baypy/issues)  
- [Documentation](https://baypy.readthedocs.io/en/latest/index.html)  
- [Installation](https://baypy.readthedocs.io/en/latest/installation.html)
- [Usage Examples](https://baypy.readthedocs.io/en/latest/examples/index.html)  
- [PyPI](https://pypi.org/project/baypy)  
- [GNU General Public License v3.0](https://github.com/AndreaBlengino/baypy/blob/master/LICENSE)

## Contributing

The baypy project welcomes your expertise and enthusiasm!  
All contributions, bug reports, bug fixes, documentation improvements, 
enhancements and ideas are welcome.  
Writing code isn't the only way to contribute to baypy. You can also:

- develop tutorials, presentations and other educational materials
- maintain and improve the documentation
- help with outreach and onboard new contributors

Have a look at the [contributing guide](https://github.com/AndreaBlengino/baypy/blob/master/.github/CONTRIBUTING.md)
